@@ -824,6 +824,13 @@ static NSImage  *fileImage = nil;
 	}
     }
 
+  // Attach the cell of an item to the document so that it has a name and
+  // can be addressed.
+  if([anObject respondsToSelector: @selector(cell)])
+    {
+      [self attachObject: [anObject cell] toParent: anObject];
+    }
+
   // Detect and add any connection the object might have.
   // This is done so that any palette items which have predefined connections will be
   // shown in the connections list.
@@ -1190,15 +1197,17 @@ static NSImage  *fileImage = nil;
   NSDebugLog(@"Owner changed for %@", sender);
 }
 
-- (void) release
+/*
+- (id) release
 {
-  [super release];
+  return [super release];
 }
+*/
 
 - (id) retain
 {
   [super retain];
-  NSDebugLog(@"Retaining document, retain count %d",[self retainCount]);
+  NSDebugLog(@"Retaining document, retain count %d", (int)[self retainCount]);
   return self;
 }
 
@@ -2490,7 +2499,7 @@ static void _real_close(GormDocument *self,
     {
       NSTableView *tv = (NSTableView *)[[(NSTableColumn*)object dataCell] controlView];
       NSTableHeaderView *th =  [tv headerView];
-      int index;
+      NSUInteger index;
 
       if (th == nil || tv == nil)
 	{
@@ -2519,7 +2528,7 @@ static void _real_close(GormDocument *self,
 
       if ([control isKindOfClass: [NSMatrix class]])
         {
-          int row, col;
+          NSInteger row, col;
           NSMatrix *matrix = (NSMatrix *)control;
 
           if ([matrix getRow: &row column: &col ofCell: cell])
@@ -2609,6 +2618,11 @@ static void _real_close(GormDocument *self,
 	      retval = NSRunAlertPanel(title, msg,_(@"OK"),_(@"Cancel"), nil, nil);
 	      prompted = YES;
 	    }
+	  else
+	    {
+		removed = NO;
+		break;
+	    }
 
 	  if (retval == NSAlertDefaultReturn)
 	    {
@@ -3236,8 +3250,12 @@ static void _real_close(GormDocument *self,
   int tag = [sender tag];
   NSEnumerator *en = [selection objectEnumerator];
   id v = nil;
-
   id prev = nil;
+
+  // Mark the document modified.
+  [self touch];
+
+  // Iterate over all in the selection and align them...
   while((v = [en nextObject]) != nil)
     {
       if([v isKindOfClass: [NSView class]])
@@ -3458,7 +3476,7 @@ static void _real_close(GormDocument *self,
  */
 - (void) setSounds: (NSArray *)snds
 {
-  ASSIGN(sounds,snds);
+  ASSIGN(sounds,[snds mutableCopy]);
 }
 
 /**
@@ -3466,7 +3484,7 @@ static void _real_close(GormDocument *self,
  */
 - (void) setImages: (NSArray *)imgs
 {
-  ASSIGN(images,imgs);
+  ASSIGN(images,[imgs mutableCopy]);
 }
 
 /**
