@@ -85,7 +85,7 @@ NSString *formatVersion(int version)
 
 + (int) currentVersion
 {
-  return appVersion(1,2,16); 
+  return appVersion(1,2,20); 
 }
 
 - (void) awakeFromNib
@@ -235,7 +235,8 @@ NSString *formatVersion(int version)
 
   NS_DURING
     {
-      id object = [NSUnarchiver unarchiveObjectWithData: data];
+      GormFilePrefsManager *object = (GormFilePrefsManager *)
+	[NSUnarchiver unarchiveObjectWithData: data];
       [gormAppVersion setStringValue: formatVersion([object version])];
       version = [object version];
       [targetVersion selectItemWithTitle: [object targetVersionName]];
@@ -307,14 +308,14 @@ NSString *formatVersion(int version)
 }
 
 // Data Source
-- (int) numberOfRowsInTableView: (NSTableView *)aTableView
+- (NSInteger) numberOfRowsInTableView: (NSTableView *)aTableView
 {
   return [currentProfile count];
 }
 
 - (id) tableView: (NSTableView *)aTableView 
 objectValueForTableColumn: (NSTableColumn *)aTableColumn 
-	     row: (int)rowIndex
+	     row: (NSInteger)rowIndex
 {
   id obj = nil;
 
@@ -336,7 +337,7 @@ objectValueForTableColumn: (NSTableColumn *)aTableColumn
 - (void) tableView: (NSTableView *)aTableView 
     setObjectValue: (id)anObject 
     forTableColumn: (NSTableColumn *)aTableColumn
-	       row: (int)rowIndex
+	       row: (NSInteger)rowIndex
 {
 }
 
