@@ -226,7 +226,7 @@ static NSMapTable	*docMap = 0;
 {
 }
 
-- (unsigned) draggingEntered: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingEntered: (id<NSDraggingInfo>)sender
 {
   NSArray   *pbTypes = nil;
   
@@ -246,12 +246,12 @@ static NSMapTable	*docMap = 0;
   return [self draggingUpdated: sender];
 }
 
-- (unsigned) draggingUpdated: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingUpdated: (id<NSDraggingInfo>)sender
 {
   if (dragType == GormLinkPboardType)
     {
       NSPoint	loc = [sender draggingLocation];
-      int	r, c;
+      NSInteger	r, c;
       int	pos;
       id	obj = nil;
 
@@ -316,7 +316,7 @@ static NSMapTable	*docMap = 0;
       }
 }
 
-- (unsigned int) draggingSourceOperationMaskForLocal: (BOOL)flag
+- (NSDragOperation) draggingSourceOperationMaskForLocal: (BOOL)flag
 {
   return NSDragOperationLink;
 }
@@ -358,7 +358,7 @@ static NSMapTable	*docMap = 0;
       NSColor *color = [NSColor colorWithCalibratedRed: 0.850980 
                                 green: 0.737255
                                 blue: 0.576471
-                                alpha: 1.0 ];
+                                alpha: 0.0 ];
 
       document = aDocument;
       
@@ -444,7 +444,7 @@ static NSMapTable	*docMap = 0;
     {
       NSPoint	loc = [theEvent locationInWindow];
       NSString	*name;
-      int	r = 0, c = 0;
+      NSInteger	r = 0, c = 0;
       int	pos = 0;
       id	obj = nil;
 
@@ -492,7 +492,7 @@ static NSMapTable	*docMap = 0;
   if (dragType == GormLinkPboardType)
     {
       NSPoint	loc = [sender draggingLocation];
-      int	r, c;
+      NSInteger	r, c;
       int	pos;
       id	obj = nil;
 
@@ -529,7 +529,7 @@ static NSMapTable	*docMap = 0;
   if (dragType == GormLinkPboardType)
     {
       NSPoint	loc = [sender draggingLocation];
-      int	r, c;
+      NSInteger	r, c;
       int	pos;
       id	obj = nil;
 
