@@ -188,8 +188,8 @@
 
 - (void) mouseDown: (NSEvent*)theEvent
 {
-  int row, column;
-  int newRow, newColumn;
+  NSInteger row, column;
+  NSInteger newRow, newColumn;
   unsigned eventMask = NSLeftMouseUpMask | NSLeftMouseDownMask
 			| NSMouseMovedMask | NSLeftMouseDraggedMask
 			| NSPeriodicMask;
@@ -318,7 +318,7 @@
 	  if(!removed)
 	    {
 	      NSString *msg = [NSString stringWithFormat: @"Could not delete file %@", path];
-	      NSLog(msg);
+	      NSLog(@"%@",msg);
 	    }
 	}
       [super deleteSelection];
