@@ -62,6 +62,8 @@
   [color setColor: [object backgroundColor]];
   [horizontalScroll setState: [object hasHorizontalScroller]?NSOnState:NSOffState];
   [verticalScroll setState: [object hasVerticalScroller]?NSOnState:NSOffState];
+  [horizontalRuler setState: [object hasHorizontalRuler]?NSOnState:NSOffState];
+  [verticalRuler setState: [object hasVerticalRuler]?NSOnState:NSOffState];
 }
 
 - (void) setObject: (id)anObject
@@ -94,6 +96,22 @@
 }
 
 
+- (void) verticalRuler: (id)sender
+{
+  /* insert your code here */
+  [super ok: sender];
+  [object setHasVerticalRuler: ([verticalRuler state] == NSOnState)];
+}
+
+
+- (void) horizontalRuler: (id)sender
+{
+  /* insert your code here */
+  [super ok: sender];
+  [object setHasHorizontalRuler: ([horizontalRuler state] == NSOnState)];
+}
+
+
 - (void) borderSelected: (id)sender
 {
   /* insert your code here */
