@@ -313,6 +313,9 @@ static BOOL currently_displaying = NO;
       if([anObject window] == nil && [anObject superview] == nil)
 	{
 	  NSDebugLog(@"#### Stand alone view: %@",_editedObject);
+	  [document attachObject: _editedObject
+		    toParent: nil];
+	  // [document openEditorForObject: _editedObject];
 	  viewWindow = [[GormViewWindow alloc] initWithView: _editedObject];
 	}
     }
@@ -322,8 +325,28 @@ static BOOL currently_displaying = NO;
 
 - (void) editedObjectFrameDidChange: (id) sender
 {
+  NSArray *allViews = allSubviews(self);
+  NSEnumerator *en = [allViews objectEnumerator];
+  id v = nil;
+
+  // Set all views under this view to not post changes...
+  while((v = [en nextObject]) != nil)
+    {
+        [v setPostsFrameChangedNotifications:NO];
+	[v setPostsBoundsChangedNotifications:NO];
+    }
+  
+  // Set the frame and the bounds...
   [self setFrame: [_editedObject frame]];
   [self setBounds: [_editedObject frame]];
+
+  // Reset all views to post changes as expected...
+  en = [allViews objectEnumerator];
+  while((v = [en nextObject]) != nil)
+    {
+      [v setPostsFrameChangedNotifications:YES];
+      [v setPostsBoundsChangedNotifications:YES];
+    }
 }
 
 - (void) frameDidChange: (id) sender
@@ -1201,7 +1224,7 @@ static BOOL currently_displaying = NO;
     }
 }
 
-- (unsigned) draggingEntered: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingEntered: (id<NSDraggingInfo>)sender
 {
   NSPasteboard	*dragPb;
   NSArray	*types;
@@ -1224,7 +1247,7 @@ static BOOL currently_displaying = NO;
     }
 }
 
-- (unsigned) draggingUpdated: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingUpdated: (id<NSDraggingInfo>)sender
 {
   return [self draggingEntered: sender];
 }
@@ -1375,7 +1398,7 @@ static BOOL currently_displaying = NO;
   return NO;
 }
 
-- (unsigned int) draggingSourceOperationMaskForLocal: (BOOL) flag
+- (NSDragOperation) draggingSourceOperationMaskForLocal: (BOOL) flag
 {
   return NSDragOperationLink;
 }
@@ -1540,6 +1563,7 @@ static BOOL done_editing;
   if ([name isEqual: NSControlTextDidEndEditingNotification] == YES)
     {
       done_editing = YES;
+      [[self document] touch];
     }
 }
 
