@@ -91,7 +91,11 @@
  */
 - (void) unsetInitialFirstResponder
 {
-  ASSIGN(_initialFirstResponder, nil);
+  if(_firstResponder == _initialFirstResponder)
+    {
+      _firstResponder = nil;
+    }
+  _initialFirstResponder = nil;
 }
 @end
 
@@ -314,7 +318,7 @@
   return nil;
 }
 
-- (unsigned) selectionCount
+- (NSUInteger) selectionCount
 {
   NSDebugLog(@"selectionCount");
   return  0;
@@ -343,18 +347,18 @@
     }
 }
 
-- (unsigned int) draggingSourceOperationMaskForLocal: (BOOL)flag
+- (NSUInteger) draggingSourceOperationMaskForLocal: (BOOL)flag
 {
   NSDebugLog(@"draggingSourceOperationMaskForLocal");
   return NSDragOperationNone;
 }
 
-- (unsigned) draggingEntered: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingEntered: (id<NSDraggingInfo>)sender
 {
   return NSDragOperationNone;
 }
 
-- (unsigned) draggingUpdated: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingUpdated: (id<NSDraggingInfo>)sender
 {
   return NSDragOperationNone;
 }
