@@ -64,8 +64,8 @@
 - (void) _stripComments
 {
   NSScanner *scanner = [NSScanner scannerWithString: fileData];
-  NSString *resultString = [NSString stringWithString: @""];
-  NSString *finalString = [NSString stringWithString: @""];
+  NSString *resultString = @"";
+  NSString *finalString = @"";
 
   // strip all of the one line comments out...
   [scanner setCharactersToBeSkipped: nil];
@@ -95,7 +95,7 @@
 - (void) _stripPreProcessor
 {
   NSScanner *scanner = [NSScanner scannerWithString: fileData];
-  NSString *resultString = [NSString stringWithString: @""];
+  NSString *resultString = @""; // [NSString stringWithString: @""];
 
   // strip all of the one line comments out...
   [scanner setCharactersToBeSkipped: nil];
