@@ -66,7 +66,7 @@
 - (void) deleteSelection;
 - (id<IBDocuments>) document;
 - (void) draggedImage: (NSImage*)i endedAt: (NSPoint)p deposited: (BOOL)f;
-- (unsigned int) draggingSourceOperationMaskForLocal: (BOOL)flag;
+- (NSDragOperation) draggingSourceOperationMaskForLocal: (BOOL)flag;
 - (id) editedObject;
 - (void) makeSelectionVisible: (BOOL)flag;
 - (id<IBEditors>) openSubeditorForObject: (id)anObject;
@@ -135,7 +135,7 @@
 
       if (pos >= 0)
 	{
-	  NSMenuItem	*item = [edited itemAtIndex: pos];
+	  NSMenuItem	*item = (NSMenuItem *)[edited itemAtIndex: pos];
 
 	  if ([theEvent clickCount] == 2)
 	    {
@@ -309,7 +309,7 @@
 	      newPos = [rep indexOfItemAtPoint: point];
 	      if (newPos < pos)
 		{
-		  NSMenuItem	*item = [edited itemAtIndex: pos];
+		  NSMenuItem	*item = (NSMenuItem *)[edited itemAtIndex: pos];
 
 		  RETAIN(item);
 		  if (newPos < 0)
@@ -320,7 +320,7 @@
 		}
 	      else if (newPos > pos)
 		{
-		  NSMenuItem	*item = [edited itemAtIndex: pos];
+		  NSMenuItem	*item = (NSMenuItem *)[edited itemAtIndex: pos];
 
 		  RETAIN(item);
 		  [edited removeItemAtIndex: pos];
@@ -522,7 +522,7 @@
    */
 }
 
-- (unsigned int) draggingSourceOperationMaskForLocal: (BOOL)flag
+- (NSDragOperation) draggingSourceOperationMaskForLocal: (BOOL)flag
 {
   if (isLinkSource == YES)
     return NSDragOperationLink;
@@ -530,7 +530,7 @@
     return NSDragOperationCopy;
 }
 
-- (unsigned) draggingEntered: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingEntered: (id<NSDraggingInfo>)sender
 {
   NSArray	*types;
 
@@ -551,7 +551,7 @@
   return [self draggingUpdated: sender];
 }
 
-- (unsigned) draggingUpdated: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingUpdated: (id<NSDraggingInfo>)sender
 {
   if (dragType == IBMenuPboardType)
     {
@@ -895,7 +895,7 @@ void _attachAll(NSMenu *menu, id document)
 {
   if ([anArray isEqual: selection] == NO)
     {
-      unsigned		count;
+      NSUInteger	count;
       NSMenuItem	*item;
 
       [selection removeAllObjects];
@@ -976,7 +976,7 @@ void _attachAll(NSMenu *menu, id document)
   return [NSArray arrayWithArray: selection];
 }
 
-- (unsigned) selectionCount
+- (NSUInteger) selectionCount
 {
   return [selection count];
 }
