@@ -39,6 +39,7 @@
 @class NSColorWell;
 @class NSForm;
 @class NSMatrix;
+@class NSPopUpButton;
 
 @interface GormTableViewAttributesInspector: IBInspector
 {
@@ -49,14 +50,14 @@
   /* scrollers */
   NSButton *verticalScrollerSwitch;
   NSButton *horizontalScrollerSwitch;
-
+  /* border and rows */
   NSMatrix *borderMatrix;
   NSForm *rowsHeightForm;
   /* options */
   NSButton *drawgridSwitch;
   NSButton *resizingSwitch;
   NSButton *reorderingSwitch;
-  
+  /* tag */
   NSForm *tagForm;
   NSColorWell *backgroundColor;
 }
